@@ -310,23 +310,24 @@ int spanconfig(char *keyword, char *args)
 	int argc;
 	int span;
 	int timing;
-	argc = res = parseargs(args, realargs, 7, ',');
-	if ((res < 5) || (res > 7)) {
+	int i;
+	argc = res = parseargs(args, realargs, 9, ',');
+	if ((res < 5) || (res > 9)) {
 		error("Incorrect number of arguments to 'span' (should be <spanno>,<timing>,<lbo>,<framing>,<coding>[, crc4 | yellow [, yellow]])\n");
 		return -1;
 	}
-	res = sscanf(realargs[0], "%i", &span);
+	res = sscanf(realargs[0], "%d", &span);
 	if (res != 1) {
 		error("Span number should be a valid span number, not '%s'\n", realargs[0]);
 		return -1;
 	}
-	res = sscanf(realargs[1], "%i", &timing);
+	res = sscanf(realargs[1], "%d", &timing);
 	if ((res != 1) || (timing < 0) || (timing > MAX_TIMING)) {
 		error("Timing should be a number from 0 to %d, not '%s'\n", 
 				MAX_TIMING,  realargs[1]);
 		return -1;
 	}
-	res = sscanf(realargs[2], "%i", &lc[spans].lbo);
+	res = sscanf(realargs[2], "%d", &lc[spans].lbo);
 	if (res != 1) {
 		error("Line build-out (LBO) should be a number from 0 to 7 (usually 0) not '%s'\n", realargs[2]);
 		return -1;
@@ -366,23 +367,22 @@ int spanconfig(char *keyword, char *args)
 		error("Coding must be one of 'ami', 'b8zs' or 'hdb3', not '%s'\n", realargs[4]);
 		return -1;
 	}
-	if (argc > 5) {
-		if (!strcasecmp(realargs[5], "yellow"))
+	for (i = 5; i < argc; i++) {
+		if (!strcasecmp(realargs[i], "yellow"))
 			lc[spans].lineconfig |= DAHDI_CONFIG_NOTOPEN;
-		else if (!strcasecmp(realargs[5], "crc4")) {
+		else if (!strcasecmp(realargs[i], "crc4"))
 			lc[spans].lineconfig |= DAHDI_CONFIG_CRC4;
-		} else {
-			error("Only valid fifth arguments are 'yellow' or 'crc4', not '%s'\n", realargs[5]);
-			return -1;
-		}
-	}
-	if (argc > 6) {
-		if (!strcasecmp(realargs[6], "yellow"))
-			lc[spans].lineconfig |= DAHDI_CONFIG_NOTOPEN;
+		else if (!strcasecmp(realargs[i], "nt"))
+			lc[spans].lineconfig |= DAHDI_CONFIG_NTTE;
+		else if (!strcasecmp(realargs[i], "te"))
+			lc[spans].lineconfig &= ~DAHDI_CONFIG_NTTE;
+		else if (!strcasecmp(realargs[i], "term"))
+			lc[spans].lineconfig |= DAHDI_CONFIG_TERM;
 		else {
-			error("Only valid sixth argument is 'yellow', not '%s'\n", realargs[6]);
+			error("Remaining arguments may be any of: 'yellow', 'crc4', 'nt', 'te', 'term', not '%s'\n", realargs[i]);
 			return -1;
 		}
+
 	}
 	lc[spans].span = span;
 	lc[spans].sync = timing;
@@ -413,7 +413,7 @@ int apply_channels(int chans[], char *argstr)
 				error("Syntax error in range '%s'.  Should be <val1>-<val2>.\n", args[x]);
 				return -1;
 			}
-			res2 =sscanf(range[0], "%i", &start);
+			res2 =sscanf(range[0], "%d", &start);
 			if (res2 != 1) {
 				error("Syntax error.  Start of range '%s' should be a number from 1 to %d\n", args[x], DAHDI_MAX_CHANNELS - 1);
 				return -1;
@@ -421,7 +421,7 @@ int apply_channels(int chans[], char *argstr)
 				error("Start of range '%s' must be between 1 and %d (not '%d')\n", args[x], DAHDI_MAX_CHANNELS - 1, start);
 				return -1;
 			}
-			res2 =sscanf(range[1], "%i", &finish);
+			res2 =sscanf(range[1], "%d", &finish);
 			if (res2 != 1) {
 				error("Syntax error.  End of range '%s' should be a number from 1 to %d\n", args[x], DAHDI_MAX_CHANNELS - 1);
 				return -1;
@@ -437,7 +437,7 @@ int apply_channels(int chans[], char *argstr)
 				chans[y]=1;
 		} else {
 			/* It's a single channel */
-			res2 =sscanf(args[x], "%i", &chan);
+			res2 =sscanf(args[x], "%d", &chan);
 			if (res2 != 1) {
 				error("Syntax error.  Channel should be a number from 1 to %d, not '%s'\n", DAHDI_MAX_CHANNELS - 1, args[x]);
 				return -1;
@@ -476,7 +476,7 @@ int parse_idle(int *i, char *s)
 
 static int parse_channel(char *channel, int *startchan)
 {
-	if (!channel || (sscanf(channel, "%i", startchan) != 1) || 
+	if (!channel || (sscanf(channel, "%d", startchan) != 1) || 
 		(*startchan < 1)) {
 		error("DACS requires a starting channel in the form ':x' where x is the channel\n");
 		return -1;
@@ -783,7 +783,7 @@ int ctcss(char *keyword, char *args)
 		error("Invalid rxtone '%s', should be a number > 0.\n", realargs[0]);
 		return -1;
 	}
-	res = sscanf(realargs[1], "%i", &rxtag);
+	res = sscanf(realargs[1], "%d", &rxtag);
 	if ((res == 1) && (rxtag < 0))
 		res = -1;
 	if (res != 1) {
@@ -1085,66 +1085,6 @@ int cor_thresh(char *keyword, char *args)
 	return 0;
 }
 
-int rad_apply_channels(int chans[], char *argstr)
-{
-	char *args[DAHDI_MAX_CHANNELS+1];
-	char *range[3];
-	int res,x, res2,y;
-	int chan;
-	int start, finish;
-	char argcopy[256];
-	res = parseargs(argstr, args, DAHDI_MAX_CHANNELS, ',');
-	if (res < 0) {
-		error("Too many arguments...  Max is %d\n", DAHDI_MAX_CHANNELS);
-		return -1;
-	}
-	for (x=0;x<res;x++) {
-		if (strchr(args[x], '-')) {
-			/* It's a range */
-			dahdi_copy_string(argcopy, args[x], sizeof(argcopy));
-			res2 = parseargs(argcopy, range, 2, '-');
-			if (res2 != 2) {
-				error("Syntax error in range '%s'.  Should be <val1>-<val2>.\n", args[x]);
-				return -1;
-			}
-			res2 =sscanf(range[0], "%i", &start);
-			if (res2 != 1) {
-				error("Syntax error.  Start of range '%s' should be a number from 1 to %d\n", args[x], DAHDI_MAX_CHANNELS - 1);
-				return -1;
-			} else if ((start < 1) || (start >= DAHDI_MAX_CHANNELS)) {
-				error("Start of range '%s' must be between 1 and %d (not '%d')\n", args[x], DAHDI_MAX_CHANNELS - 1, start);
-				return -1;
-			}
-			res2 =sscanf(range[1], "%i", &finish);
-			if (res2 != 1) {
-				error("Syntax error.  End of range '%s' should be a number from 1 to %d\n", args[x], DAHDI_MAX_CHANNELS - 1);
-				return -1;
-			} else if ((finish < 1) || (finish >= DAHDI_MAX_CHANNELS)) {
-				error("end of range '%s' must be between 1 and %d (not '%d')\n", args[x], DAHDI_MAX_CHANNELS - 1, finish);
-				return -1;
-			}
-			if (start > finish) {
-				error("Range '%s' should start before it ends\n", args[x]);
-				return -1;
-			}
-			for (y=start;y<=finish;y++)
-				chans[y]=1;
-		} else {
-			/* It's a single channel */
-			res2 =sscanf(args[x], "%i", &chan);
-			if (res2 != 1) {
-				error("Syntax error.  Channel should be a number from 1 to %d, not '%s'\n", DAHDI_MAX_CHANNELS - 1, args[x]);
-				return -1;
-			} else if ((chan < 1) || (chan >= DAHDI_MAX_CHANNELS)) {
-				error("Channel must be between 1 and %d (not '%d')\n", DAHDI_MAX_CHANNELS - 1, chan);
-				return -1;
-			}
-			chans[chan]=1;
-		}		
-	}
-	return res;
-}
-
 static int rad_chanconfig(char *keyword, char *args)
 {
 	int chans[DAHDI_MAX_CHANNELS];
@@ -1154,7 +1094,7 @@ static int rad_chanconfig(char *keyword, char *args)
 
 	toneindex = 1;
 	bzero(chans, sizeof(chans));
-	res = rad_apply_channels(chans, args);
+	res = apply_channels(chans, args);
 	if (res <= 0)
 		return -1;
 	for (x=1;x<DAHDI_MAX_CHANNELS;x++) {
@@ -1280,15 +1220,17 @@ static void printconfig(int fd)
 	       "Echo Canceller(s): %s\n"
 	       "Configuration\n"
 	       "======================\n\n", vi.version, vi.echo_canceller);
-	for (x=0;x<spans;x++) 
+	for (x = 0; x < spans; x++) {
 		printf("SPAN %d: %3s/%4s Build-out: %s\n",
-		       x+1, ( lc[x].lineconfig & DAHDI_CONFIG_D4 ? "D4" :
-			      lc[x].lineconfig & DAHDI_CONFIG_ESF ? "ESF" :
-			      lc[x].lineconfig & DAHDI_CONFIG_CCS ? "CCS" : "CAS" ),
-			( lc[x].lineconfig & DAHDI_CONFIG_AMI ? "AMI" :
-			  lc[x].lineconfig & DAHDI_CONFIG_B8ZS ? "B8ZS" :
-			  lc[x].lineconfig & DAHDI_CONFIG_HDB3 ? "HDB3" : "???" ),
-			lbostr[lc[x].lbo]);
+		       lc[x].span,
+		       (lc[x].lineconfig & DAHDI_CONFIG_D4 ? "D4" :
+			lc[x].lineconfig & DAHDI_CONFIG_ESF ? "ESF" :
+			lc[x].lineconfig & DAHDI_CONFIG_CCS ? "CCS" : "CAS"),
+		       (lc[x].lineconfig & DAHDI_CONFIG_AMI ? "AMI" :
+			lc[x].lineconfig & DAHDI_CONFIG_B8ZS ? "B8ZS" :
+			lc[x].lineconfig & DAHDI_CONFIG_HDB3 ? "HDB3" : "???"),
+		       lbostr[lc[x].lbo]);
+	}
 	for (x=0;x<numdynamic;x++) {
 		printf("Dynamic span %d: driver %s, addr %s, channels %d, timing %d\n",
 		       x +1, zds[x].driver, zds[x].addr, zds[x].numchans, zds[x].timing);
@@ -1610,8 +1552,61 @@ finish:
 		if (needupdate && ioctl(fd, DAHDI_CHANCONFIG, &cc[x])) {
 			fprintf(stderr, "DAHDI_CHANCONFIG failed on channel %d: %s (%d)\n", x, strerror(errno), errno);
 			if (errno == EINVAL) {
-				fprintf(stderr, "Did you forget that FXS interfaces are configured with FXO signalling\n"
-					"and that FXO interfaces use FXS signalling?\n");
+				/* give helpful suggestions on signaling errors */
+				fprintf(stderr, "Selected signaling not "
+						"supported\n");
+				fprintf(stderr, "Possible causes:\n");
+				switch(cc[x].sigtype) {
+				case DAHDI_SIG_FXOKS:
+				case DAHDI_SIG_FXOLS:
+				case DAHDI_SIG_FXOGS:
+					fprintf(stderr, "\tFXO signaling is "
+						"being used on a FXO interface"
+						" (use a FXS signaling variant"
+						")\n");
+					fprintf(stderr, "\tRBS signaling is "
+						"being used on a E1 CCS span"
+						"\n");
+					break;
+				case DAHDI_SIG_FXSKS:
+				case DAHDI_SIG_FXSLS:
+				case DAHDI_SIG_FXSGS:
+					fprintf(stderr, "\tFXS signaling is "
+						"being used on a FXS interface"
+						" (use a FXO signaling variant"
+						")\n");
+					fprintf(stderr, "\tRBS signaling is "
+						"being used on a E1 CCS span"
+						"\n");
+					break;
+				case DAHDI_SIG_EM:
+					fprintf(stderr, "\te&m signaling is "
+						"being used on a E1 line (use"
+						" e&me1)\n");
+					break;
+				case DAHDI_SIG_EM_E1:
+					fprintf(stderr, "\te&me1 signaling is "
+						"being used on a T1 line (use "
+						"e&m)\n");
+					fprintf(stderr, "\tRBS signaling is "
+						"being used on a E1 CCS span"
+						"\n");
+					break;
+				case DAHDI_SIG_HARDHDLC:
+					fprintf(stderr, "\thardhdlc is being "
+						"used on a TE12x (use dchan)\n"
+						);
+					break;
+				case DAHDI_SIG_HDLCFCS:
+					fprintf(stderr, "\tdchan is being used"
+						" on a BRI span (use hardhdlc)"
+						"\n");
+					break;
+				default:
+					break;
+				}
+				fprintf(stderr, "\tSignaling is being assigned"
+					" to channel 16 of an E1 CAS span\n");
 			}
 			close(fd);
 			exit(1);
