@@ -21,6 +21,8 @@
  */
 
 #define	_GNU_SOURCE	/* for memrchr() */
+#include <unistd.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <assert.h>
@@ -31,7 +33,7 @@
 #include "astribank_usb.h"
 #include "debug.h"
 
-static const char rcsid[] = "$Id: astribank_usb.c 7474 2009-11-04 17:33:46Z tzafrir $";
+static const char rcsid[] = "$Id: astribank_usb.c 7908 2010-01-13 16:26:15Z tzafrir $";
 
 #define	DBG_MASK	0x01
 #define	TIMEOUT	500
